@@ -7,6 +7,7 @@ use actix_web::{
     App, HttpResponse, HttpServer, Responder,
 };
 use actix_web_lab::body;
+use tracing::info;
 
 #[get("/")]
 async fn index() -> impl Responder {
@@ -32,7 +33,7 @@ async fn main() -> io::Result<()> {
     env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));
 
     let bind = ("127.0.0.1", 8080);
-    log::info!("staring server at http://{}:{}", &bind.0, &bind.1);
+    info!("staring server at http://{}:{}", &bind.0, &bind.1);
 
     HttpServer::new(|| App::new().service(index))
         .workers(1)
